You are viewing a plain text version of this content. The canonical link for it is here.
Posted to commits@activemq.apache.org by cl...@apache.org on 2015/04/28 18:02:27 UTC

[22/57] [abbrv] [partial] activemq-6 git commit: ACTIVEMQ6-1 Artemis rename

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQRegistryImpl.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQRegistryImpl.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQRegistryImpl.java
index 870ca0c..01268ad 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQRegistryImpl.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQRegistryImpl.java
@@ -15,7 +15,7 @@
  * limitations under the License.
  */
 
-package org.apache.activemq.service.extensions.xa.recovery;
+package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
 public class ActiveMQRegistryImpl implements ActiveMQRegistry
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXARecoveryLogger.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXARecoveryLogger.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXARecoveryLogger.java
index 9ae511f..15707ae 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXARecoveryLogger.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXARecoveryLogger.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.xa.recovery;
+package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
-import org.apache.activemq.api.core.client.ClientSessionFactory;
+import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
 import org.jboss.logging.BasicLogger;
 import org.jboss.logging.Logger;
 import org.jboss.logging.annotations.Cause;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
index 3616976..7e4c3bd 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceRecovery.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.xa.recovery;
+package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
 import javax.transaction.xa.XAResource;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.activemq.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
 
 /**
  * A XAResourceRecovery instance that can be used to recover any JMS provider.
@@ -31,19 +31,19 @@ import org.apache.activemq.api.core.TransportConfiguration;
  * To enable this add the following to the jbossts-properties file
  * <pre>
  * &lt;property name="com.arjuna.ats.jta.recovery.XAResourceRecovery.ACTIVEMQ1"
- *                 value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.core.remoting.impl.invm.InVMConnectorFactory"/&gt;
+ *                 value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.invm.InVMConnectorFactory"/&gt;
  * </pre>
  * <p>
  * you'll need something like this if the ActiveMQ Server is remote
  * <pre>
  *      &lt;property name="com.arjuna.ats.jta.recovery.XAResourceRecovery.ACTIVEMQ2"
- *                  value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616"/&gt;
+ *                  value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616"/&gt;
  * </pre>
  * <p>
  * you'll need something like this if the ActiveMQ Server is remote and has failover configured
  * <pre>
  *             &lt;property name="com.arjuna.ats.jta.recovery.XAResourceRecovery.ACTIVEMQ2"
- *                       value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616;org.apache.activemq.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost2,port=61617"/&gt;
+ *                       value="org.apache.activemq.jms.server.recovery.ActiveMQXAResourceRecovery;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost,port=61616;org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory,guest,guest,host=localhost2,port=61617"/&gt;
  * </pre>
  */
 public class ActiveMQXAResourceRecovery

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
index dc3e1c8..9ce285b 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/ActiveMQXAResourceWrapper.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.xa.recovery;
+package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
 import java.util.Arrays;
 
@@ -22,14 +22,14 @@ import javax.transaction.xa.XAException;
 import javax.transaction.xa.XAResource;
 import javax.transaction.xa.Xid;
 
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.api.core.ActiveMQExceptionType;
-import org.apache.activemq.api.core.ActiveMQNotConnectedException;
-import org.apache.activemq.api.core.client.ClientSession;
-import org.apache.activemq.api.core.client.ClientSessionFactory;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.api.core.client.ServerLocator;
-import org.apache.activemq.api.core.client.SessionFailureListener;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.ActiveMQExceptionType;
+import org.apache.activemq.artemis.api.core.ActiveMQNotConnectedException;
+import org.apache.activemq.artemis.api.core.client.ClientSession;
+import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.api.core.client.ServerLocator;
+import org.apache.activemq.artemis.api.core.client.SessionFailureListener;
 
 /**
  * XAResourceWrapper.

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/XARecoveryConfig.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/XARecoveryConfig.java b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/XARecoveryConfig.java
index 2f3a948..67f801f 100644
--- a/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/XARecoveryConfig.java
+++ b/artemis-service-extensions/src/main/java/org/apache/activemq/artemis/service/extensions/xa/recovery/XARecoveryConfig.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.xa.recovery;
+package org.apache.activemq.artemis.service.extensions.xa.recovery;
 
 import java.util.Arrays;
 
-import org.apache.activemq.api.core.DiscoveryGroupConfiguration;
-import org.apache.activemq.api.core.TransportConfiguration;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.api.core.client.ServerLocator;
-import org.apache.activemq.jms.client.ActiveMQConnectionFactory;
+import org.apache.activemq.artemis.api.core.DiscoveryGroupConfiguration;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.api.core.client.ServerLocator;
+import org.apache.activemq.artemis.jms.client.ActiveMQConnectionFactory;
 
 /**
  *

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/DummyTransactionManagerLocator.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/DummyTransactionManagerLocator.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/DummyTransactionManagerLocator.java
index 1097031..c6ce175 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/DummyTransactionManagerLocator.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/DummyTransactionManagerLocator.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.transactions;
+package org.apache.activemq.artemis.service.extensions.tests.transactions;
 
-import org.apache.activemq.service.extensions.transactions.TransactionManagerLocator;
+import org.apache.activemq.artemis.service.extensions.transactions.TransactionManagerLocator;
 
 import javax.transaction.HeuristicMixedException;
 import javax.transaction.HeuristicRollbackException;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/TransactionManagerLocatorTest.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/TransactionManagerLocatorTest.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/TransactionManagerLocatorTest.java
index f928423..5216a00 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/TransactionManagerLocatorTest.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/transactions/TransactionManagerLocatorTest.java
@@ -14,9 +14,9 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.transactions;
+package org.apache.activemq.artemis.service.extensions.tests.transactions;
 
-import org.apache.activemq.service.extensions.ServiceUtils;
+import org.apache.activemq.artemis.service.extensions.ServiceUtils;
 import org.junit.Assert;
 import org.junit.Test;
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
index 052957c..32cd969 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ActiveMQXAResourceWrapperImplTest.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.xa;
+package org.apache.activemq.artemis.service.extensions.tests.xa;
 
 import javax.transaction.xa.XAResource;
 
 import java.util.HashMap;
 import java.util.Map;
 
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapper;
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapperImpl;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapper;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapperImpl;
 import org.junit.Test;
 
 import static org.jgroups.util.Util.assertEquals;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockActiveMQResourceWrapperFactory.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockActiveMQResourceWrapperFactory.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockActiveMQResourceWrapperFactory.java
index 5933b5a..1d6f0ad 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockActiveMQResourceWrapperFactory.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockActiveMQResourceWrapperFactory.java
@@ -14,13 +14,13 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.xa;
+package org.apache.activemq.artemis.service.extensions.tests.xa;
 
 import javax.transaction.xa.XAResource;
 import java.util.Map;
 
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapper;
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapperFactory;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapper;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapperFactory;
 
 public class MockActiveMQResourceWrapperFactory implements ActiveMQXAResourceWrapperFactory
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockXAResource.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockXAResource.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockXAResource.java
index 8651a98..0d5c25c 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockXAResource.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/MockXAResource.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.xa;
+package org.apache.activemq.artemis.service.extensions.tests.xa;
 
 import javax.transaction.xa.XAException;
 import javax.transaction.xa.XAResource;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ServiceUtilsTest.java
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ServiceUtilsTest.java b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ServiceUtilsTest.java
index a278a3b..af2819a 100644
--- a/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ServiceUtilsTest.java
+++ b/artemis-service-extensions/src/test/java/org/apache/activemq/artemis/service/extensions/tests/xa/ServiceUtilsTest.java
@@ -14,16 +14,16 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.service.extensions.tests.xa;
+package org.apache.activemq.artemis.service.extensions.tests.xa;
 
 import java.lang.reflect.Field;
 import java.lang.reflect.Method;
 import java.util.ArrayList;
 import java.util.List;
 
-import org.apache.activemq.service.extensions.ServiceUtils;
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapperFactory;
-import org.apache.activemq.service.extensions.xa.ActiveMQXAResourceWrapperFactoryImpl;
+import org.apache.activemq.artemis.service.extensions.ServiceUtils;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapperFactory;
+import org.apache.activemq.artemis.service.extensions.xa.ActiveMQXAResourceWrapperFactoryImpl;
 import org.junit.Test;
 
 import static org.jgroups.util.Util.assertTrue;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.artemis.service.extensions.transactions.TransactionManagerLocator
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.artemis.service.extensions.transactions.TransactionManagerLocator b/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.artemis.service.extensions.transactions.TransactionManagerLocator
new file mode 100644
index 0000000..1f52699
--- /dev/null
+++ b/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.artemis.service.extensions.transactions.TransactionManagerLocator
@@ -0,0 +1 @@
+org.apache.activemq.artemis.service.extensions.tests.transactions.DummyTransactionManagerLocator
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.service.extensions.transactions.TransactionManagerLocator
----------------------------------------------------------------------
diff --git a/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.service.extensions.transactions.TransactionManagerLocator b/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.service.extensions.transactions.TransactionManagerLocator
deleted file mode 100644
index c4bc639..0000000
--- a/artemis-service-extensions/src/test/resources/META-INF/services/org.apache.activemq.service.extensions.transactions.TransactionManagerLocator
+++ /dev/null
@@ -1 +0,0 @@
-org.apache.activemq.service.extensions.tests.transactions.DummyTransactionManagerLocator
\ No newline at end of file

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-tools/pom.xml b/artemis-tools/pom.xml
index affc8d0..d221401 100644
--- a/artemis-tools/pom.xml
+++ b/artemis-tools/pom.xml
@@ -19,11 +19,11 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-tools</artifactId>
+   <artifactId>artemis-tools</artifactId>
    <packaging>jar</packaging>
    <name>ActiveMQ Artemis Tools</name>
 
@@ -40,12 +40,12 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-server</artifactId>
+         <artifactId>artemis-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-jms-server</artifactId>
+         <artifactId>artemis-jms-server</artifactId>
          <version>${project.version}</version>
       </dependency>
    </dependencies>
@@ -61,7 +61,7 @@
             <configuration>
                <archive>
                   <manifest>
-                     <mainClass>org.apache.activemq.tools.Main</mainClass>
+                     <mainClass>org.apache.activemq.artemis.tools.Main</mainClass>
                   </manifest>
                </archive>
                <descriptorRefs>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ActiveMQToolsLogger.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ActiveMQToolsLogger.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ActiveMQToolsLogger.java
index 4c8e49f..9646049 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ActiveMQToolsLogger.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ActiveMQToolsLogger.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import org.jboss.logging.BasicLogger;
 import org.jboss.logging.Logger;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/DataTool.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/DataTool.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/DataTool.java
index 8c63598..58a6b1e 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/DataTool.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/DataTool.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.io.File;
 import java.util.ArrayList;
 
-import org.apache.activemq.core.config.impl.ConfigurationImpl;
-import org.apache.activemq.core.journal.SequentialFileFactory;
-import org.apache.activemq.core.journal.impl.JournalImpl;
-import org.apache.activemq.core.journal.impl.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.core.config.impl.ConfigurationImpl;
+import org.apache.activemq.artemis.core.journal.SequentialFileFactory;
+import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.NIOSequentialFileFactory;
 
 public class DataTool
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ExportJournal.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ExportJournal.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ExportJournal.java
index 2742b0a..d2c9339 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ExportJournal.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ExportJournal.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.io.BufferedOutputStream;
 import java.io.File;
@@ -22,13 +22,13 @@ import java.io.FileOutputStream;
 import java.io.PrintStream;
 import java.util.List;
 
-import org.apache.activemq.core.journal.RecordInfo;
-import org.apache.activemq.core.journal.SequentialFileFactory;
-import org.apache.activemq.core.journal.impl.JournalFile;
-import org.apache.activemq.core.journal.impl.JournalImpl;
-import org.apache.activemq.core.journal.impl.JournalReaderCallback;
-import org.apache.activemq.core.journal.impl.NIOSequentialFileFactory;
-import org.apache.activemq.utils.Base64;
+import org.apache.activemq.artemis.core.journal.RecordInfo;
+import org.apache.activemq.artemis.core.journal.SequentialFileFactory;
+import org.apache.activemq.artemis.core.journal.impl.JournalFile;
+import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.JournalReaderCallback;
+import org.apache.activemq.artemis.core.journal.impl.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.utils.Base64;
 
 /**
  * Use this class to export the journal data. You can use it as a main class or through its static method {@link #exportJournal(String, String, String, int, int, String)}

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ImportJournal.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/Main.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/Main.java
index 9eee57f..c239b15 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/Main.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/Main.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 public class Main
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintData.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintPages.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintPages.java
index 30dfe02..ed4dcdc 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintPages.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintPages.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.util.ArrayList;
 import java.util.HashMap;
@@ -27,34 +27,34 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQBuffers;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.core.config.impl.ConfigurationImpl;
-import org.apache.activemq.core.journal.PreparedTransactionInfo;
-import org.apache.activemq.core.journal.RecordInfo;
-import org.apache.activemq.core.journal.SequentialFileFactory;
-import org.apache.activemq.core.journal.impl.JournalImpl;
-import org.apache.activemq.core.journal.impl.NIOSequentialFileFactory;
-import org.apache.activemq.core.paging.PagedMessage;
-import org.apache.activemq.core.paging.PagingManager;
-import org.apache.activemq.core.paging.PagingStore;
-import org.apache.activemq.core.paging.PagingStoreFactory;
-import org.apache.activemq.core.paging.cursor.PagePosition;
-import org.apache.activemq.core.paging.cursor.impl.PagePositionImpl;
-import org.apache.activemq.core.paging.impl.Page;
-import org.apache.activemq.core.paging.impl.PageTransactionInfoImpl;
-import org.apache.activemq.core.paging.impl.PagingManagerImpl;
-import org.apache.activemq.core.paging.impl.PagingStoreFactoryNIO;
-import org.apache.activemq.core.persistence.StorageManager;
-import org.apache.activemq.core.persistence.impl.journal.JournalRecordIds;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.CursorAckRecordEncoding;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.PageUpdateTXEncoding;
-import org.apache.activemq.core.persistence.impl.nullpm.NullStorageManager;
-import org.apache.activemq.core.settings.HierarchicalRepository;
-import org.apache.activemq.core.settings.impl.AddressSettings;
-import org.apache.activemq.core.settings.impl.HierarchicalObjectRepository;
-import org.apache.activemq.utils.ExecutorFactory;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffers;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.core.config.impl.ConfigurationImpl;
+import org.apache.activemq.artemis.core.journal.PreparedTransactionInfo;
+import org.apache.activemq.artemis.core.journal.RecordInfo;
+import org.apache.activemq.artemis.core.journal.SequentialFileFactory;
+import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.core.paging.PagedMessage;
+import org.apache.activemq.artemis.core.paging.PagingManager;
+import org.apache.activemq.artemis.core.paging.PagingStore;
+import org.apache.activemq.artemis.core.paging.PagingStoreFactory;
+import org.apache.activemq.artemis.core.paging.cursor.PagePosition;
+import org.apache.activemq.artemis.core.paging.cursor.impl.PagePositionImpl;
+import org.apache.activemq.artemis.core.paging.impl.Page;
+import org.apache.activemq.artemis.core.paging.impl.PageTransactionInfoImpl;
+import org.apache.activemq.artemis.core.paging.impl.PagingManagerImpl;
+import org.apache.activemq.artemis.core.paging.impl.PagingStoreFactoryNIO;
+import org.apache.activemq.artemis.core.persistence.StorageManager;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.CursorAckRecordEncoding;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.PageUpdateTXEncoding;
+import org.apache.activemq.artemis.core.persistence.impl.nullpm.NullStorageManager;
+import org.apache.activemq.artemis.core.settings.HierarchicalRepository;
+import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
+import org.apache.activemq.artemis.core.settings.impl.HierarchicalObjectRepository;
+import org.apache.activemq.artemis.utils.ExecutorFactory;
 
 public class PrintPages // NO_UCD (unused code)
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/TransferQueue.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/TransferQueue.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/TransferQueue.java
index e8ee457..d13aa60 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/TransferQueue.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/TransferQueue.java
@@ -14,23 +14,23 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.util.HashMap;
 import java.util.LinkedList;
 import java.util.Map;
 
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.api.core.TransportConfiguration;
-import org.apache.activemq.api.core.client.ClientConsumer;
-import org.apache.activemq.api.core.client.ClientMessage;
-import org.apache.activemq.api.core.client.ClientProducer;
-import org.apache.activemq.api.core.client.ClientSession;
-import org.apache.activemq.api.core.client.ClientSessionFactory;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.api.core.client.ServerLocator;
-import org.apache.activemq.core.remoting.impl.netty.NettyConnectorFactory;
-import org.apache.activemq.core.remoting.impl.netty.TransportConstants;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.api.core.client.ClientConsumer;
+import org.apache.activemq.artemis.api.core.client.ClientMessage;
+import org.apache.activemq.artemis.api.core.client.ClientProducer;
+import org.apache.activemq.artemis.api.core.client.ClientSession;
+import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.api.core.client.ServerLocator;
+import org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory;
+import org.apache.activemq.artemis.core.remoting.impl.netty.TransportConstants;
 
 public class TransferQueue // NO_UCD (unused code)
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataConstants.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataConstants.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataConstants.java
index 8881df1..34fe96c 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataConstants.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataConstants.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 /**
  * The constants shared by <code>org.apache.activemq.tools.XmlDataImporter</code> and

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataExporter.java
----------------------------------------------------------------------
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataExporter.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataExporter.java
index 9aa5603..37829a3 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataExporter.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataExporter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import javax.xml.stream.XMLOutputFactory;
 import javax.xml.stream.XMLStreamException;
@@ -36,61 +36,61 @@ import java.util.concurrent.ExecutorService;
 import java.util.concurrent.Executors;
 import java.util.concurrent.ScheduledExecutorService;
 
-import org.apache.activemq.api.core.ActiveMQBuffer;
-import org.apache.activemq.api.core.ActiveMQBuffers;
-import org.apache.activemq.api.core.ActiveMQException;
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.Pair;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.api.jms.JMSFactoryType;
-import org.apache.activemq.core.config.Configuration;
-import org.apache.activemq.core.config.impl.ConfigurationImpl;
-import org.apache.activemq.core.journal.Journal;
-import org.apache.activemq.core.journal.PreparedTransactionInfo;
-import org.apache.activemq.core.journal.RecordInfo;
-import org.apache.activemq.core.journal.SequentialFileFactory;
-import org.apache.activemq.core.journal.TransactionFailureCallback;
-import org.apache.activemq.core.journal.impl.JournalImpl;
-import org.apache.activemq.core.journal.impl.NIOSequentialFileFactory;
-import org.apache.activemq.core.message.BodyEncoder;
-import org.apache.activemq.core.paging.PagedMessage;
-import org.apache.activemq.core.paging.PagingManager;
-import org.apache.activemq.core.paging.PagingStore;
-import org.apache.activemq.core.paging.PagingStoreFactory;
-import org.apache.activemq.core.paging.cursor.PagePosition;
-import org.apache.activemq.core.paging.cursor.impl.PagePositionImpl;
-import org.apache.activemq.core.paging.impl.Page;
-import org.apache.activemq.core.paging.impl.PageTransactionInfoImpl;
-import org.apache.activemq.core.paging.impl.PagingManagerImpl;
-import org.apache.activemq.core.paging.impl.PagingStoreFactoryNIO;
-import org.apache.activemq.core.persistence.impl.journal.DescribeJournal;
-import org.apache.activemq.core.persistence.impl.journal.DescribeJournal.MessageDescribe;
-import org.apache.activemq.core.persistence.impl.journal.DescribeJournal.ReferenceDescribe;
-import org.apache.activemq.core.persistence.impl.journal.JournalRecordIds;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.AckDescribe;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.CursorAckRecordEncoding;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.PageUpdateTXEncoding;
-import org.apache.activemq.core.persistence.impl.journal.JournalStorageManager.PersistentQueueBindingEncoding;
-import org.apache.activemq.core.server.ActiveMQServerLogger;
-import org.apache.activemq.core.server.JournalType;
-import org.apache.activemq.core.server.LargeServerMessage;
-import org.apache.activemq.core.server.ServerMessage;
-import org.apache.activemq.core.settings.HierarchicalRepository;
-import org.apache.activemq.core.settings.impl.AddressSettings;
-import org.apache.activemq.core.settings.impl.HierarchicalObjectRepository;
-import org.apache.activemq.jms.persistence.config.PersistedConnectionFactory;
-import org.apache.activemq.jms.persistence.config.PersistedDestination;
-import org.apache.activemq.jms.persistence.config.PersistedBindings;
-import org.apache.activemq.jms.persistence.config.PersistedType;
-import org.apache.activemq.jms.persistence.impl.journal.JMSJournalStorageManagerImpl;
-import org.apache.activemq.utils.Base64;
-import org.apache.activemq.utils.ExecutorFactory;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffer;
+import org.apache.activemq.artemis.api.core.ActiveMQBuffers;
+import org.apache.activemq.artemis.api.core.ActiveMQException;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.Pair;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.api.jms.JMSFactoryType;
+import org.apache.activemq.artemis.core.config.Configuration;
+import org.apache.activemq.artemis.core.config.impl.ConfigurationImpl;
+import org.apache.activemq.artemis.core.journal.Journal;
+import org.apache.activemq.artemis.core.journal.PreparedTransactionInfo;
+import org.apache.activemq.artemis.core.journal.RecordInfo;
+import org.apache.activemq.artemis.core.journal.SequentialFileFactory;
+import org.apache.activemq.artemis.core.journal.TransactionFailureCallback;
+import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.core.message.BodyEncoder;
+import org.apache.activemq.artemis.core.paging.PagedMessage;
+import org.apache.activemq.artemis.core.paging.PagingManager;
+import org.apache.activemq.artemis.core.paging.PagingStore;
+import org.apache.activemq.artemis.core.paging.PagingStoreFactory;
+import org.apache.activemq.artemis.core.paging.cursor.PagePosition;
+import org.apache.activemq.artemis.core.paging.cursor.impl.PagePositionImpl;
+import org.apache.activemq.artemis.core.paging.impl.Page;
+import org.apache.activemq.artemis.core.paging.impl.PageTransactionInfoImpl;
+import org.apache.activemq.artemis.core.paging.impl.PagingManagerImpl;
+import org.apache.activemq.artemis.core.paging.impl.PagingStoreFactoryNIO;
+import org.apache.activemq.artemis.core.persistence.impl.journal.DescribeJournal;
+import org.apache.activemq.artemis.core.persistence.impl.journal.DescribeJournal.MessageDescribe;
+import org.apache.activemq.artemis.core.persistence.impl.journal.DescribeJournal.ReferenceDescribe;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalRecordIds;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.AckDescribe;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.CursorAckRecordEncoding;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.PageUpdateTXEncoding;
+import org.apache.activemq.artemis.core.persistence.impl.journal.JournalStorageManager.PersistentQueueBindingEncoding;
+import org.apache.activemq.artemis.core.server.ActiveMQServerLogger;
+import org.apache.activemq.artemis.core.server.JournalType;
+import org.apache.activemq.artemis.core.server.LargeServerMessage;
+import org.apache.activemq.artemis.core.server.ServerMessage;
+import org.apache.activemq.artemis.core.settings.HierarchicalRepository;
+import org.apache.activemq.artemis.core.settings.impl.AddressSettings;
+import org.apache.activemq.artemis.core.settings.impl.HierarchicalObjectRepository;
+import org.apache.activemq.artemis.jms.persistence.config.PersistedConnectionFactory;
+import org.apache.activemq.artemis.jms.persistence.config.PersistedDestination;
+import org.apache.activemq.artemis.jms.persistence.config.PersistedBindings;
+import org.apache.activemq.artemis.jms.persistence.config.PersistedType;
+import org.apache.activemq.artemis.jms.persistence.impl.journal.JMSJournalStorageManagerImpl;
+import org.apache.activemq.artemis.utils.Base64;
+import org.apache.activemq.artemis.utils.ExecutorFactory;
 
 /**
  * Read the journal, page, and large-message data from a stopped instance of ActiveMQ and save it in an XML format to
  * a file.  It uses the StAX <code>javax.xml.stream.XMLStreamWriter</code> for speed and simplicity.  Output can be
- * read by <code>org.apache.activemq.core.persistence.impl.journal.XmlDataImporter</code>.
+ * read by <code>org.apache.activemq.artemis.core.persistence.impl.journal.XmlDataImporter</code>.
  */
 public final class XmlDataExporter
 {

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataImporter.java
----------------------------------------------------------------------
diff --git a/artemis-web/pom.xml b/artemis-web/pom.xml
index 96fa59a..cbb1810 100644
--- a/artemis-web/pom.xml
+++ b/artemis-web/pom.xml
@@ -19,11 +19,11 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-web</artifactId>
+   <artifactId>artemis-web</artifactId>
    <packaging>jar</packaging>
    <name>ActiveMQ Artemis Web</name>
 
@@ -34,12 +34,12 @@
    <dependencies>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-dto</artifactId>
+         <artifactId>artemis-dto</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-bootstrap</artifactId>
+         <artifactId>artemis-bootstrap</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
@@ -60,7 +60,7 @@
       <!-- this is for the log assertion -->
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-commons</artifactId>
+         <artifactId>artemis-commons</artifactId>
          <version>${project.version}</version>
       </dependency>
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-web/src/main/java/org/apache/activemq/artemis/component/WebServerComponent.java
----------------------------------------------------------------------
diff --git a/artemis-web/src/main/java/org/apache/activemq/artemis/component/WebServerComponent.java b/artemis-web/src/main/java/org/apache/activemq/artemis/component/WebServerComponent.java
index 310bf1b..665f03b 100644
--- a/artemis-web/src/main/java/org/apache/activemq/artemis/component/WebServerComponent.java
+++ b/artemis-web/src/main/java/org/apache/activemq/artemis/component/WebServerComponent.java
@@ -14,12 +14,12 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.component;
+package org.apache.activemq.artemis.component;
 
-import org.apache.activemq.components.ExternalComponent;
-import org.apache.activemq.dto.AppDTO;
-import org.apache.activemq.dto.ComponentDTO;
-import org.apache.activemq.dto.WebServerDTO;
+import org.apache.activemq.artemis.components.ExternalComponent;
+import org.apache.activemq.artemis.dto.AppDTO;
+import org.apache.activemq.artemis.dto.ComponentDTO;
+import org.apache.activemq.artemis.dto.WebServerDTO;
 import org.eclipse.jetty.server.Connector;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.handler.DefaultHandler;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-web/src/test/java/org/apache/activemq/artemis/test/WebServerComponentTest.java
----------------------------------------------------------------------
diff --git a/artemis-web/src/test/java/org/apache/activemq/artemis/test/WebServerComponentTest.java b/artemis-web/src/test/java/org/apache/activemq/artemis/test/WebServerComponentTest.java
index c170635..71e1860 100644
--- a/artemis-web/src/test/java/org/apache/activemq/artemis/test/WebServerComponentTest.java
+++ b/artemis-web/src/test/java/org/apache/activemq/artemis/test/WebServerComponentTest.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.test;
+package org.apache.activemq.artemis.test;
 
 import io.netty.bootstrap.Bootstrap;
 import io.netty.channel.Channel;
@@ -33,8 +33,8 @@ import io.netty.handler.codec.http.HttpObject;
 import io.netty.handler.codec.http.HttpRequest;
 import io.netty.handler.codec.http.HttpVersion;
 import io.netty.util.CharsetUtil;
-import org.apache.activemq.component.WebServerComponent;
-import org.apache.activemq.dto.WebServerDTO;
+import org.apache.activemq.artemis.component.WebServerComponent;
+import org.apache.activemq.artemis.dto.WebServerDTO;
 import org.junit.Assert;
 import org.junit.Before;
 import org.junit.Test;

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-website/pom.xml
----------------------------------------------------------------------
diff --git a/artemis-website/pom.xml b/artemis-website/pom.xml
index ebd800e..1962679 100644
--- a/artemis-website/pom.xml
+++ b/artemis-website/pom.xml
@@ -19,43 +19,43 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-website</artifactId>
+   <artifactId>artemis-website</artifactId>
    <packaging>jar</packaging>
    <name>ActiveMQ Artemis Web</name>
 
     <dependencies>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-core-client</artifactId>
+            <artifactId>artemis-core-client</artifactId>
             <version>${project.version}</version>
         </dependency>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-jms-client</artifactId>
+            <artifactId>artemis-jms-client</artifactId>
             <version>${project.version}</version>
         </dependency>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-server</artifactId>
+            <artifactId>artemis-server</artifactId>
             <version>${project.version}</version>
         </dependency>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-jms-server</artifactId>
+            <artifactId>artemis-jms-server</artifactId>
             <version>${project.version}</version>
         </dependency>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-journal</artifactId>
+            <artifactId>artemis-journal</artifactId>
             <version>${project.version}</version>
         </dependency>
         <dependency>
             <groupId>org.apache.activemq</groupId>
-            <artifactId>activemq-selector</artifactId>
+            <artifactId>artemis-selector</artifactId>
             <version>${project.version}</version>
         </dependency>
     </dependencies>
@@ -88,16 +88,16 @@
 
                      <dependencySourceIncludes>
                         <!-- include ONLY dependencies I control -->
-                        <dependencySourceInclude>org.apache.activemq:activemq-core-client</dependencySourceInclude>
-                        <dependencySourceInclude>org.apache.activemq:activemq-jms-client</dependencySourceInclude>
-                        <dependencySourceInclude>org.apache.activemq:activemq-server</dependencySourceInclude>
-                        <dependencySourceInclude>org.apache.activemq:activemq-jms-server</dependencySourceInclude>
-                        <dependencySourceInclude>org.apache.activemq:activemq-journal</dependencySourceInclude>
-                        <dependencySourceInclude>org.apache.activemq:activemq-selector</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-core-client</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-jms-client</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-server</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-jms-server</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-journal</dependencySourceInclude>
+                        <dependencySourceInclude>org.apache.activemq:artemis-selector</dependencySourceInclude>
                      </dependencySourceIncludes>
                      <quiet>false</quiet>
                      <aggregate>true</aggregate>
-                     <excludePackageNames>org.apache.activemq.core:org.apache.activemq.utils</excludePackageNames>
+                     <excludePackageNames>org.apache.activemq.artemis.core:org.apache.activemq.artemis.utils</excludePackageNames>
                   </configuration>
                </execution>
             </executions>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-website/src/main/resources/examples/index.html
----------------------------------------------------------------------
diff --git a/artemis-website/src/main/resources/examples/index.html b/artemis-website/src/main/resources/examples/index.html
index 4bd3ac7..2c2a746 100644
--- a/artemis-website/src/main/resources/examples/index.html
+++ b/artemis-website/src/main/resources/examples/index.html
@@ -30,7 +30,7 @@
 <div id="navigation">
     <div class="wrapper">
         <ul>
-            <li><a href="../index.html">ActiveMQ 6.0</a></li>
+            <li><a href="../index.html">ActiveMQ Artemis</a></li>
         </ul>        <div></div>
     </div>
 </div>
@@ -41,10 +41,10 @@
         </div>
         <div class="message">
 
-        <h1>Apache ActiveMQ Examples</h1>
+        <h1>Apache ActiveMQ Artemis Examples</h1>
 
-        <p>Apache ActiveMQ comes with over 90 runnable examples. These can be found in the examples directory in the root of the
-        distribution folder. There are examples covering JMS as well as all the protocols and functionality that Apache ActiveMQ
+        <p>Apache ActiveMQ Artemis comes with over 90 runnable examples. These can be found in the examples directory in the root of the
+        distribution folder. There are examples covering JMS as well as all the protocols and functionality that Apache ActiveMQ Artemis
         supports.</p>
 
         <p>Each example has its own instructions as to how they can be run, but for most of them it is as simple as running

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-website/src/main/resources/index.html
----------------------------------------------------------------------
diff --git a/artemis-website/src/main/resources/index.html b/artemis-website/src/main/resources/index.html
index 9b5a623..7ae3fcb 100644
--- a/artemis-website/src/main/resources/index.html
+++ b/artemis-website/src/main/resources/index.html
@@ -30,7 +30,7 @@
 <div id="navigation">
     <div class="wrapper">
         <ul>
-            <li><a href="index.html">ActiveMQ 6.0</a></li>
+            <li><a href="index.html">ActiveMQ Artemis</a></li>
         </ul>        <div></div>
     </div>
 </div>
@@ -40,7 +40,7 @@
             <img src="images/activemq-logo.png" alt="ActiveMQ logo"/>
         </div>
         <div class="message">
-            <h1>ActiveMQ 6.0</h1>
+            <h1>ActiveMQ Artemis</h1>
             ActiveMQ's next generation of messaging
 
             <div></div>
@@ -53,7 +53,7 @@
             <li><a target="_blank" href="api/index.html">API</a></li>
             <li><a target="_blank" href="user-manual/index.html">User Manual</a></li>
             <li><a href="examples/index.html">Examples</a></li>
-            <li><a href="http://activemq.apache.org/activemq6">Apache ActiveMQ Artemis Website</a></li>
+            <li><a href="http://activemq.apache.org/artemis">Apache ActiveMQ Artemis Website</a></li>
         </ul>
         <div></div>
     </div>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-website/src/main/resources/user-manual/index.html
----------------------------------------------------------------------
diff --git a/artemis-website/src/main/resources/user-manual/index.html b/artemis-website/src/main/resources/user-manual/index.html
index 6490318..338e956 100644
--- a/artemis-website/src/main/resources/user-manual/index.html
+++ b/artemis-website/src/main/resources/user-manual/index.html
@@ -19,7 +19,7 @@ under the License.
 
 <h1>User Manual</h1>
 
-<p>If you are seeing this message, it is because the User Manual was not built during the Apache ActiveMQ Artemis build.  To
+<p>If you are seeing this message, it is because the User Manual was not built during the Apache ActiveMQ Artemis-6 build.  To
 build Apache ActiveMQ Artemis with the User Manual you must use the maven release profile:
 <code>mvn clean install -Prelease</code>.</p>
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/pom.xml
----------------------------------------------------------------------
diff --git a/distribution/artemis/pom.xml b/distribution/artemis/pom.xml
index 5c37416..8a8fa65 100644
--- a/distribution/artemis/pom.xml
+++ b/distribution/artemis/pom.xml
@@ -21,8 +21,8 @@
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-artemis-distribution</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-distribution</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
    <artifactId>apache-activemq-artemis</artifactId>
@@ -39,97 +39,97 @@
      <!-- ActiveMQ artifacts -->
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-boot</artifactId>
+         <artifactId>artemis-boot</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-server</artifactId>
+         <artifactId>artemis-server</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-dto</artifactId>
+         <artifactId>artemis-dto</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-bootstrap</artifactId>
+         <artifactId>artemis-bootstrap</artifactId>
          <version>${project.version}</version>
       </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-jms-server</artifactId>
+        <artifactId>artemis-jms-server</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-jms-client</artifactId>
+        <artifactId>artemis-jms-client</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-tools</artifactId>
+        <artifactId>artemis-tools</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-ra</artifactId>
+        <artifactId>artemis-ra</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-spring-integration</artifactId>
+        <artifactId>artemis-spring-integration</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-vertx-integration</artifactId>
+        <artifactId>artemis-vertx-integration</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq.rest</groupId>
-        <artifactId>activemq-rest</artifactId>
+        <artifactId>artemis-rest</artifactId>
         <version>${project.version}</version>
      </dependency>
      <dependency>
         <groupId>org.apache.activemq</groupId>
-        <artifactId>activemq-aerogear-integration</artifactId>
+        <artifactId>artemis-aerogear-integration</artifactId>
         <version>${project.version}</version>
      </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-web</artifactId>
+         <artifactId>artemis-web</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-core-client</artifactId>
+         <artifactId>artemis-core-client</artifactId>
          <version>${project.version}</version>
       </dependency>
        <dependency>
            <groupId>org.apache.activemq</groupId>
-           <artifactId>activemq-amqp-protocol</artifactId>
+           <artifactId>artemis-amqp-protocol</artifactId>
            <version>${project.version}</version>
        </dependency>
        <dependency>
            <groupId>org.apache.activemq</groupId>
-           <artifactId>activemq-stomp-protocol</artifactId>
+           <artifactId>artemis-stomp-protocol</artifactId>
            <version>${project.version}</version>
        </dependency>
        <dependency>
            <groupId>org.apache.activemq</groupId>
-           <artifactId>activemq-openwire-protocol</artifactId>
+           <artifactId>artemis-openwire-protocol</artifactId>
            <version>${project.version}</version>
        </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-native</artifactId>
+         <artifactId>artemis-native</artifactId>
          <version>${project.version}</version>
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-website</artifactId>
+         <artifactId>artemis-website</artifactId>
          <version>${project.version}</version>
       </dependency>
 
@@ -173,7 +173,7 @@
       </dependency>
       <dependency>
          <groupId>org.apache.activemq</groupId>
-         <artifactId>activemq-website</artifactId>
+         <artifactId>artemis-website</artifactId>
          <version>${project.version}</version>
          <classifier>javadoc</classifier>
       </dependency>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/src/main/assembly/dep.xml
----------------------------------------------------------------------
diff --git a/distribution/artemis/src/main/assembly/dep.xml b/distribution/artemis/src/main/assembly/dep.xml
index c792469..1ca9844 100644
--- a/distribution/artemis/src/main/assembly/dep.xml
+++ b/distribution/artemis/src/main/assembly/dep.xml
@@ -37,7 +37,7 @@
         <unpack>false</unpack>
         <useTransitiveDependencies>false</useTransitiveDependencies>
         <includes>
-           <include>org.apache.activemq:activemq-boot</include>
+           <include>org.apache.activemq:artemis-boot</include>
         </includes>
       </dependencySet>
 
@@ -47,25 +47,25 @@
          <includes>
 
             <!-- modules -->
-            <include>org.apache.activemq:activemq-bootstrap</include>
-            <include>org.apache.activemq:activemq-commons</include>
-            <include>org.apache.activemq:activemq-core-client</include>
-            <include>org.apache.activemq:activemq-dto</include>
-            <include>org.apache.activemq:activemq-jms-client</include>
-            <include>org.apache.activemq:activemq-jms-server</include>
-            <include>org.apache.activemq:activemq-journal</include>
-            <include>org.apache.activemq:activemq-native</include>
-            <include>org.apache.activemq:activemq-amqp-protocol</include>
-            <include>org.apache.activemq:activemq-openwire-protocol</include>
-            <include>org.apache.activemq:activemq-proton-plug</include>
-            <include>org.apache.activemq:activemq-stomp-protocol</include>
-            <include>org.apache.activemq:activemq-ra</include>
-            <include>org.apache.activemq:activemq-selector</include>
-            <include>org.apache.activemq:activemq-server</include>
-            <include>org.apache.activemq:activemq-service-extensions</include>
-            <include>org.apache.activemq:activemq-tools</include>
-            <include>org.apache.activemq:activemq-web</include>
-            <include>org.apache.activemq.rest:activemq-rest</include>
+            <include>org.apache.activemq:artemis-bootstrap</include>
+            <include>org.apache.activemq:artemis-commons</include>
+            <include>org.apache.activemq:artemis-core-client</include>
+            <include>org.apache.activemq:artemis-dto</include>
+            <include>org.apache.activemq:artemis-jms-client</include>
+            <include>org.apache.activemq:artemis-jms-server</include>
+            <include>org.apache.activemq:artemis-journal</include>
+            <include>org.apache.activemq:artemis-native</include>
+            <include>org.apache.activemq:artemis-amqp-protocol</include>
+            <include>org.apache.activemq:artemis-openwire-protocol</include>
+            <include>org.apache.activemq:artemis-proton-plug</include>
+            <include>org.apache.activemq:artemis-stomp-protocol</include>
+            <include>org.apache.activemq:artemis-ra</include>
+            <include>org.apache.activemq:artemis-selector</include>
+            <include>org.apache.activemq:artemis-server</include>
+            <include>org.apache.activemq:artemis-service-extensions</include>
+            <include>org.apache.activemq:artemis-tools</include>
+            <include>org.apache.activemq:artemis-web</include>
+            <include>org.apache.activemq.rest:artemis-rest</include>
             <!-- dependencies -->
             <include>org.apache.geronimo.specs:geronimo-jms_2.0_spec</include>
             <include>org.jboss.logmanager:jboss-logmanager</include>
@@ -86,7 +86,7 @@
             <include>org.fusesource.hawtbuf:hawtbuf</include>
          </includes>
          <!--excludes>
-            <exclude>org.apache.activemq:activemq-website</exclude>
+            <exclude>org.apache.activemq:artemis-website</exclude>
          </excludes-->
          <outputDirectory>lib</outputDirectory>
          <unpack>false</unpack>
@@ -94,7 +94,7 @@
       <!-- native -->
       <dependencySet>
          <includes>
-            <include>org.apache.activemq:activemq-native</include>
+            <include>org.apache.activemq:artemis-native</include>
          </includes>
          <outputDirectory>bin</outputDirectory>
          <unpack>true</unpack>
@@ -106,17 +106,17 @@
       </dependencySet>
       <dependencySet>
          <includes>
-            <include>org.apache.activemq:activemq-website</include>
+            <include>org.apache.activemq:artemis-website</include>
          </includes>
          <excludes>
-            <exclude>org.apache.activemq:activemq-website:jar:javadoc</exclude>
+            <exclude>org.apache.activemq:artemis-website:jar:javadoc</exclude>
          </excludes>
          <outputDirectory>web</outputDirectory>
          <unpack>true</unpack>
       </dependencySet>
       <dependencySet>
          <includes>
-            <include>org.apache.activemq:activemq-website:jar:javadoc</include>
+            <include>org.apache.activemq:artemis-website:jar:javadoc</include>
          </includes>
          <outputDirectory>web/api</outputDirectory>
          <unpack>true</unpack>
@@ -132,12 +132,12 @@
    <fileSets>
       <!-- schema -->
       <fileSet>
-         <directory>${activemq.basedir}/activemq-server/src/main/resources/schema/</directory>
+         <directory>${activemq.basedir}/artemis-server/src/main/resources/schema/</directory>
          <outputDirectory>schema</outputDirectory>
          <lineEnding>keep</lineEnding>
       </fileSet>
       <fileSet>
-         <directory>${activemq.basedir}/activemq-jms-server/src/main/resources/schema/</directory>
+         <directory>${activemq.basedir}/artemis-jms-server/src/main/resources/schema/</directory>
          <outputDirectory>schema</outputDirectory>
          <lineEnding>keep</lineEnding>
       </fileSet>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/src/main/resources/README.html
----------------------------------------------------------------------
diff --git a/distribution/artemis/src/main/resources/README.html b/distribution/artemis/src/main/resources/README.html
index f0c0503..1b7b1a9 100644
--- a/distribution/artemis/src/main/resources/README.html
+++ b/distribution/artemis/src/main/resources/README.html
@@ -22,7 +22,7 @@ under the License.
 <head>
    <meta content="text/html; charset=ISO-8859-1"
          http-equiv="content-type">
-   <title>Apache ActiveMQ README</title>
+   <title>Apache ActiveMQ Artemis README</title>
 </head>
 <body>
 
@@ -57,11 +57,11 @@ $ ./activemq stop</br></br>
 
 <h2>Documentation</h2>
 
-The broker comes shipped with an in depth user manual and a bunch of examples to help you get started.  The manual is accessible from the broker website.  Start the broker then navigate to the <a href="http://localhost:8161">Apache ActiveMQ</a>.</br></br>
+The broker comes shipped with an in depth user manual and a bunch of examples to help you get started.  The manual is accessible from the broker website.  Start the broker then navigate to the <a href="http://localhost:8161">Apache ActiveMQ Artemis</a>.</br></br>
 
 The examples are shipped inside the distribution folder under "examples"</br></br>
 
-<h2>Release Notes - ActiveMQ 6.0.0</h2>
+<h2>Release Notes - ActiveMQ Artemis 1.0.0</h2>
 
-The ActiveMQ 6.0.0 release notes can be found in the <a href="https://issues.apache.org/jira/secure/ReleaseNote.jspa?projectId=12315920&version=12328953">Apache ActiveMQ project JIRA</a>.
+The ActiveMQ Artemis 1.0.0 release notes can be found in the <a href="https://issues.apache.org/jira/secure/ReleaseNote.jspa?projectId=12315920&version=12328953">Apache ActiveMQ Artemis project JIRA</a>.
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/src/main/resources/bin/activemq
----------------------------------------------------------------------
diff --git a/distribution/artemis/src/main/resources/bin/activemq b/distribution/artemis/src/main/resources/bin/activemq
index 4b99fd6..ab76bac 100755
--- a/distribution/artemis/src/main/resources/bin/activemq
+++ b/distribution/artemis/src/main/resources/bin/activemq
@@ -6,9 +6,9 @@
 # to you under the Apache License, Version 2.0 (the
 # "License"); you may not use this file except in compliance
 # with the License.  You may obtain a copy of the License at
-# 
+#
 #   http://www.apache.org/licenses/LICENSE-2.0
-# 
+#
 # Unless required by applicable law or agreed to in writing,
 # software distributed under the License is distributed on an
 # "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -46,7 +46,7 @@ fi
 
 # Set Defaults Properties
 JAVA_ARGS="-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods -Xms512M -Xmx1024M"
-CLASSPATH="$ACTIVEMQ_HOME/lib/activemq-boot.jar"
+CLASSPATH="$ACTIVEMQ_HOME/lib/artemis-boot.jar"
 
 # OS specific support.
 cygwin=false;
@@ -105,4 +105,4 @@ exec "$JAVACMD" $JAVA_ARGS $ACTIVEMQ_CLUSTER_PROPS \
     -Dactivemq.home="$ACTIVEMQ_HOME" \
     -Djava.library.path="$ACTIVEMQ_HOME/bin/lib/linux-i686:$ACTIVEMQ_INSTANCE/bin/lib/linux-x86_64" \
     $DEBUG_ARGS \
-    org.apache.activemq.boot.ActiveMQ $@
+    org.apache.activemq.artemis.boot.ActiveMQ $@

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/src/main/resources/bin/activemq.cmd
----------------------------------------------------------------------
diff --git a/distribution/artemis/src/main/resources/bin/activemq.cmd b/distribution/artemis/src/main/resources/bin/activemq.cmd
index 8ab6163..344c9df 100755
--- a/distribution/artemis/src/main/resources/bin/activemq.cmd
+++ b/distribution/artemis/src/main/resources/bin/activemq.cmd
@@ -6,9 +6,9 @@ rem regarding copyright ownership.  The ASF licenses this file
 rem to you under the Apache License, Version 2.0 (the
 rem "License"); you may not use this file except in compliance
 rem with the License.  You may obtain a copy of the License at
-rem 
+rem
 rem   http://www.apache.org/licenses/LICENSE-2.0
-rem 
+rem
 rem Unless required by applicable law or agreed to in writing,
 rem software distributed under the License is distributed on an
 rem "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
@@ -53,11 +53,11 @@ set JAVA_ARGS=-XX:+UseParallelGC -XX:+AggressiveOpts -XX:+UseFastAccessorMethods
 rem "Create full JVM Args"
 set JVM_ARGS=%JAVA_ARGS%
 if not "%ACTIVEMQ_CLUSTER_PROPS%"=="" set JVM_ARGS=%JVM_ARGS% %ACTIVEMQ_CLUSTER_PROPS%
-set JVM_ARGS=%JVM_ARGS% -classpath "%ACTIVEMQ_HOME%\lib\activemq-boot.jar"
+set JVM_ARGS=%JVM_ARGS% -classpath "%ACTIVEMQ_HOME%\lib\artemis-boot.jar"
 set JVM_ARGS=%JVM_ARGS% -Dactivemq.home="%ACTIVEMQ_HOME%"
 if not "%DEBUG_ARGS%"=="" set JVM_ARGS=%JVM_ARGS% %DEBUG_ARGS%
 
-"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.boot.ActiveMQ %*
+"%_JAVACMD%" %JVM_ARGS% org.apache.activemq.artemis.boot.ActiveMQ %*
 
 :END
 endlocal

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/artemis/src/main/resources/licenses/bin/NOTICE
----------------------------------------------------------------------
diff --git a/distribution/artemis/src/main/resources/licenses/bin/NOTICE b/distribution/artemis/src/main/resources/licenses/bin/NOTICE
index 6303fab..28c29dc 100644
--- a/distribution/artemis/src/main/resources/licenses/bin/NOTICE
+++ b/distribution/artemis/src/main/resources/licenses/bin/NOTICE
@@ -1,4 +1,4 @@
-Apache ActiveMQ
+Apache ActiveMQ Artemis
 Copyright [2014-2015] The Apache Software Foundation
 
 This product includes software developed at

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/distribution/pom.xml
----------------------------------------------------------------------
diff --git a/distribution/pom.xml b/distribution/pom.xml
index 7a959fc..721bd1e 100644
--- a/distribution/pom.xml
+++ b/distribution/pom.xml
@@ -23,11 +23,11 @@ under the License.
 
    <parent>
       <groupId>org.apache.activemq</groupId>
-      <artifactId>activemq-pom</artifactId>
-      <version>10.0.0-SNAPSHOT</version>
+      <artifactId>artemis-pom</artifactId>
+      <version>1.0.0-SNAPSHOT</version>
    </parent>
 
-   <artifactId>activemq-artemis-distribution</artifactId>
+   <artifactId>artemis-distribution</artifactId>
    <packaging>pom</packaging>
    <name>ActiveMQ Artemis Distribution</name>
 
@@ -48,7 +48,7 @@ under the License.
    </dependencies>
 
    <modules>
-      <module>activemq</module>
+      <module>artemis</module>
    </modules>
 
    <build>

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/docs/README.html
----------------------------------------------------------------------
diff --git a/docs/README.html b/docs/README.html
index 95bed87..def9391 100644
--- a/docs/README.html
+++ b/docs/README.html
@@ -22,12 +22,12 @@ under the License.
 <head>
    <meta content="text/html; charset=ISO-8859-1"
          http-equiv="content-type">
-   <title>Apache ActiveMQ Release Notes</title>
+   <title>Apache ActiveMQ Artemis Release Notes</title>
 </head>
 <body>
 
-<h2>Release Notes - Apache ActiveMQ 6.0.0</h2>
+<h2>Release Notes - Apache ActiveMQ Artemis 1.0.0</h2>
 
-The Apache ActiveMQ 6.0.0 release notes can be found in the <a href="https://issues.apache.org/jira/secure/ReleaseNote.jspa?projectId=12315920&version=12328953">Apache ActiveMQ project JIRA</a>.
+The Apache ActiveMQ Artemis 1.0.0 release notes can be found in the <a href="https://issues.apache.org/jira/secure/ReleaseNote.jspa?projectId=12315920&version=12328953">Apache ActiveMQ Artemis project JIRA</a>.
 
 For more info on what this release has to offer please refer to the quick start guide or the user manual. Enjoy!!

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/docs/quickstart-guide/en/running.md
----------------------------------------------------------------------
diff --git a/docs/quickstart-guide/en/running.md b/docs/quickstart-guide/en/running.md
index a3b2ce5..0a9a0d9 100644
--- a/docs/quickstart-guide/en/running.md
+++ b/docs/quickstart-guide/en/running.md
@@ -40,7 +40,7 @@ to do start running the broker instance is execute:
 Now that the broker is running, you can optionally run some of the included 
 examples to verify the the broker is running properly.
 
-To stop the Apache ActiveMQ instance you will use the same `activemq` script, but with 
+To stop the Apache ActiveMQ Artemis instance you will use the same `activemq` script, but with 
 the `stop argument`.  Example:
 
     /var/lib/mybroker/bin/activemq stop

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/docs/user-manual/en/README.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/README.md b/docs/user-manual/en/README.md
index 1d35c43..4ea32c8 100644
--- a/docs/user-manual/en/README.md
+++ b/docs/user-manual/en/README.md
@@ -1,7 +1,7 @@
 ![ActiveMQ logo](images/activemq-logo.jpg)
 
-Apache ActiveMQ User Manual
+Apache ActiveMQ Artemis User Manual
 ====================
 
-The User manual is an in depth manual on all aspects of Apache ActiveMQ
+The User manual is an in depth manual on all aspects of Apache ActiveMQ Artemis
 

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/docs/user-manual/en/SUMMARY.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/SUMMARY.md b/docs/user-manual/en/SUMMARY.md
index 9bd05b8..48724fc 100644
--- a/docs/user-manual/en/SUMMARY.md
+++ b/docs/user-manual/en/SUMMARY.md
@@ -13,7 +13,7 @@
 * [The Client Classpath](client-classpath.md)
 * [Examples](examples.md)
 * [Routing Messages With Wild Cards](wildcard-routing.md)
-* [Understanding the Apache ActiveMQ Wildcard Syntax](wildcard-syntax.md)
+* [Understanding the Apache ActiveMQ Artemis Wildcard Syntax](wildcard-syntax.md)
 * [Filter Expressions](filter-expressions.md)
 * [Persistence](persistence.md)
 * [Configuring Transports](configuring-transports.md)
@@ -45,7 +45,7 @@
 * [Thread management](thread-pooling.md)
 * [Logging](logging.md)
 * [REST Interface](rest.md)
-* [Embedding Apache ActiveMQ](embedding-activemq.md)
+* [Embedding Apache ActiveMQ Artemis](embedding-activemq.md)
 * [Spring Integration](spring-integration.md)
 * [AeroGear Integration](aerogear-integration.md)
 * [VertX Integration](vertx-integration.md)

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/docs/user-manual/en/aerogear-integration.md
----------------------------------------------------------------------
diff --git a/docs/user-manual/en/aerogear-integration.md b/docs/user-manual/en/aerogear-integration.md
index df1f3e0..2a83f4d 100644
--- a/docs/user-manual/en/aerogear-integration.md
+++ b/docs/user-manual/en/aerogear-integration.md
@@ -2,7 +2,7 @@
 
 AeroGears push technology provides support for different push
 notification technologies like Google Cloud Messaging, Apple's APNs or
-Mozilla's SimplePush. Apache ActiveMQ allows you to configure a Connector
+Mozilla's SimplePush. Apache ActiveMQ Artemis allows you to configure a Connector
 Service that will consume messages from a queue and forward them to an
 AeroGear push server and subsequently sent as notifications to mobile
 devices.
@@ -13,7 +13,7 @@ AeroGear Connector services are configured in the connector-services
 configuration:
 
         <connector-service name="aerogear-connector">
-        <factory-class>org.apache.activemq.integration.aerogear.AeroGearConnectorServiceFactory</factory-class>
+        <factory-class>org.apache.activemq.artemis.integration.aerogear.AeroGearConnectorServiceFactory</factory-class>
         <param key="endpoint" value="endpoint"/>
         <param key="queue" value="jms.queue.aerogearQueue"/>
         <param key="application-id" value="an applicationid"/>
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ImportJournal.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ImportJournal.java
index ac1e24f..b1d0284 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ImportJournal.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/ImportJournal.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.io.BufferedReader;
 import java.io.File;
@@ -27,11 +27,11 @@ import java.util.Map;
 import java.util.Properties;
 import java.util.concurrent.atomic.AtomicInteger;
 
-import org.apache.activemq.core.journal.RecordInfo;
-import org.apache.activemq.core.journal.impl.JournalImpl;
-import org.apache.activemq.core.journal.impl.JournalRecord;
-import org.apache.activemq.core.journal.impl.NIOSequentialFileFactory;
-import org.apache.activemq.utils.Base64;
+import org.apache.activemq.artemis.core.journal.RecordInfo;
+import org.apache.activemq.artemis.core.journal.impl.JournalImpl;
+import org.apache.activemq.artemis.core.journal.impl.JournalRecord;
+import org.apache.activemq.artemis.core.journal.impl.NIOSequentialFileFactory;
+import org.apache.activemq.artemis.utils.Base64;
 
 /**
  * Use this class to import the journal data from a listed file. You can use it as a main class or
@@ -47,7 +47,7 @@ import org.apache.activemq.utils.Base64;
  * Example:
  *
  * <pre>
  * java -cp activemq-core.jar org.apache.activemq.core.journal.impl.ExportJournal /journalDir activemq-data amq 2 10485760 /tmp/export.dat
  * </pre>
  */
 public class ImportJournal

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/Main.java
----------------------------------------------------------------------
@@ -47,7 +47,7 @@ import org.apache.activemq.utils.Base64;
  *
  * <pre>
- * java -cp activemq-core.jar org.apache.activemq.core.journal.impl.ExportJournal /journalDir activemq-data amq 2 10485760 /tmp/export.dat
+ * java -cp activemq-core.jar org.apache.activemq.artemis.core.journal.impl.ExportJournal /journalDir activemq-data amq 2 10485760 /tmp/export.dat
  * </pre>
  */
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintData.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintData.java
index 7d6ad53..4b92bad 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintData.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintData.java
@@ -14,15 +14,15 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 import java.io.File;
 
-import org.apache.activemq.core.persistence.impl.journal.DescribeJournal;
-import org.apache.activemq.core.server.impl.FileLockNodeManager;
+import org.apache.activemq.artemis.core.persistence.impl.journal.DescribeJournal;
+import org.apache.activemq.artemis.core.server.impl.FileLockNodeManager;
 
 /**
  * Writes a human-readable interpretation of the contents of a ActiveMQ {@link org.apache.activemq.core.journal.Journal}.
  * <p>
  * To run this class with Maven, use:
  *

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/PrintPages.java
----------------------------------------------------------------------
@@ -14,15 +14,15 @@
 
 /**
- * Writes a human-readable interpretation of the contents of a ActiveMQ {@link org.apache.activemq.core.journal.Journal}.
+ * Writes a human-readable interpretation of the contents of a ActiveMQ {@link org.apache.activemq.artemis.core.journal.Journal}.
  * <p>
  * To run this class with Maven, use:
diff --git a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataImporter.java b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataImporter.java
index baf6a28..8ce2563 100644
--- a/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataImporter.java
+++ b/artemis-tools/src/main/java/org/apache/activemq/artemis/tools/XmlDataImporter.java
@@ -14,7 +14,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.apache.activemq.tools;
+package org.apache.activemq.artemis.tools;
 
 
 import javax.xml.stream.XMLInputFactory;
@@ -34,26 +34,27 @@ import java.util.HashMap;
 import java.util.Map;
 import java.util.UUID;
 
-import org.apache.activemq.api.core.Message;
-import org.apache.activemq.api.core.SimpleString;
-import org.apache.activemq.api.core.TransportConfiguration;
-import org.apache.activemq.api.core.client.ClientMessage;
-import org.apache.activemq.api.core.client.ClientProducer;
-import org.apache.activemq.api.core.client.ClientRequestor;
-import org.apache.activemq.api.core.client.ClientSession;
-import org.apache.activemq.api.core.client.ClientSessionFactory;
-import org.apache.activemq.api.core.client.ActiveMQClient;
-import org.apache.activemq.api.core.client.ServerLocator;
-import org.apache.activemq.api.core.management.ManagementHelper;
-import org.apache.activemq.api.core.management.ResourceNames;
-import org.apache.activemq.core.message.impl.MessageImpl;
-import org.apache.activemq.core.remoting.impl.netty.NettyConnectorFactory;
-import org.apache.activemq.core.remoting.impl.netty.TransportConstants;
-import org.apache.activemq.core.server.ActiveMQServerLogger;
-import org.apache.activemq.utils.Base64;
+import org.apache.activemq.artemis.api.core.Message;
+import org.apache.activemq.artemis.api.core.SimpleString;
+import org.apache.activemq.artemis.api.core.TransportConfiguration;
+import org.apache.activemq.artemis.api.core.client.ClientMessage;
+import org.apache.activemq.artemis.api.core.client.ClientProducer;
+import org.apache.activemq.artemis.api.core.client.ClientRequestor;
+import org.apache.activemq.artemis.api.core.client.ClientSession;
+import org.apache.activemq.artemis.api.core.client.ClientSessionFactory;
+import org.apache.activemq.artemis.api.core.client.ActiveMQClient;
+import org.apache.activemq.artemis.api.core.client.ServerLocator;
+import org.apache.activemq.artemis.api.core.management.ManagementHelper;
+import org.apache.activemq.artemis.api.core.management.ResourceNames;
+import org.apache.activemq.artemis.core.message.impl.MessageImpl;
+import org.apache.activemq.artemis.core.remoting.impl.netty.NettyConnectorFactory;
+import org.apache.activemq.artemis.core.remoting.impl.netty.TransportConstants;
+import org.apache.activemq.artemis.core.server.ActiveMQServerLogger;
+import org.apache.activemq.artemis.utils.UUIDGenerator;
+import org.apache.activemq.artemis.utils.Base64;
 
 /**
  * Read XML output from <code>org.apache.activemq.core.persistence.impl.journal.XmlDataExporter</code>, create a core session, and
  * send the messages to a running instance of ActiveMQ.  It uses the StAX <code>javax.xml.stream.XMLStreamReader</code>
  * for speed and simplicity.
  */
@@ -86,7 +87,7 @@ public final class XmlDataImporter
 
    /**
     * This is the normal constructor for programmatic access to the
     * <code>org.apache.activemq.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
     * in uses auto-commit for sends.
     * <p/>
     * If the session needs to be transactional then use the constructor which takes 2 sessions.
@@ -102,7 +103,7 @@ public final class XmlDataImporter
 
    /**
     * This is the normal constructor for programmatic access to the
     * <code>org.apache.activemq.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
     * in uses auto-commit for sends.
     * <p/>
     * If the session needs to be transactional then use the constructor which takes 2 sessions.
@@ -240,7 +241,7 @@ public final class XmlDataImporter
       Byte priority = 0;
       Long expiration = 0L;
       Long timestamp = 0L;
-      org.apache.activemq.utils.UUID userId = null;
+      org.apache.activemq.artemis.utils.UUID userId = null;
       ArrayList<String> queues = new ArrayList<>();
 
       // get message's attributes
@@ -262,7 +263,7 @@ public final class XmlDataImporter
                timestamp = Long.parseLong(reader.getAttributeValue(i));
                break;
             case XmlDataConstants.MESSAGE_USER_ID:
-               userId = org.apache.activemq.utils.UUIDGenerator.getInstance().generateUUID();
+               userId = UUIDGenerator.getInstance().generateUUID();
                break;
          }
       }

http://git-wip-us.apache.org/repos/asf/activemq-6/blob/8f52a622/artemis-web/pom.xml
----------------------------------------------------------------------
@@ -34,26 +34,27 @@ import java.util.HashMap;
 
 /**
- * Read XML output from <code>org.apache.activemq.core.persistence.impl.journal.XmlDataExporter</code>, create a core session, and
+ * Read XML output from <code>org.apache.activemq.artemis.core.persistence.impl.journal.XmlDataExporter</code>, create a core session, and
  * send the messages to a running instance of ActiveMQ.  It uses the StAX <code>javax.xml.stream.XMLStreamReader</code>
  * for speed and simplicity.
@@ -86,7 +87,7 @@ public final class XmlDataImporter
    /**
     * This is the normal constructor for programmatic access to the
-    * <code>org.apache.activemq.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
+    * <code>org.apache.activemq.artemis.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
     * in uses auto-commit for sends.
     * <p/>
@@ -102,7 +103,7 @@ public final class XmlDataImporter
    /**
     * This is the normal constructor for programmatic access to the
-    * <code>org.apache.activemq.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
+    * <code>org.apache.activemq.artemis.core.persistence.impl.journal.XmlDataImporter</code> if the session passed
     * in uses auto-commit for sends.
     * <p/>